Private Keys 
############

By default, ``moccasin`` discourages keeping your private keys in plain text, and it's much better to encrypt them. However, if you insist, you may also pass private keys to your scripts via the command line.

.. code-block:: bash 

    mox run deploy --private-key 0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef

